<?php

namespace Litecms\Profile\Http\Controllers;

use Exception;
use Litecms\Profile\Actions\ProfileWorkflow;
use Litecms\Profile\Http\Requests\ProfileWorkflowRequest;
use Litecms\Profile\Http\Resources\ProfileResource;
use Litecms\Profile\Models\Profile;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class ProfileWorkflowController extends BaseController
{
    /**
     * Action controller function for profile.
     *
     * @param Model $profile
     * @param action next action for the profile.
     *
     * @return Response
     */
    public function __invoke(ProfileWorkflowRequest $request, Profile $profile, $trasition)
    {
        try {
            $profile = ProfileWorkflow::run($request, $profile, $trasition);
            $data = new ProfileResource($profile);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('profile::profile.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('profile/profile/' . $profile->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('profile/profile/' . $profile->getRouteKey()))
                ->redirect();
        }
    }
}
