<?php

namespace Litecms\Profile\Policies;

use Litecms\Profile\Models\Profile;
use Litepie\User\Interfaces\UserPolicyInterface;

trait ProfileAction
{

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function copy(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('profile.profile.action.copy')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    function empty(UserPolicyInterface $authUser, Profile $profile) {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('profile.profile.action.empty')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function transfer(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('profile.profile.action.transfer')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function delete(UserPolicyInterface $authUser, Profile $profile)
    {


        if ($authUser->canDo('profile.profile.action.delete')) {
            return true;
        }

        return false;
    }


}
