<?php

namespace Litecms\Profile\Policies;

use Litecms\Profile\Models\Profile;
use Litepie\User\Interfaces\UserPolicyInterface;

trait ProfileWorkflow
{

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->canDo('profile.profile.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function submit(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->canDo('profile.profile.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function publish(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->canDo('profile.profile.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function unpublish(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->canDo('profile.profile.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function archive(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->canDo('profile.profile.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function unarchive(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->canDo('profile.profile.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function reject(UserPolicyInterface $authUser, Profile $profile)
    {
        if ($authUser->canDo('profile.profile.reject')) {
            return true;
        }

        return false;
    }

}
